==> dojo_1.5.0+dfsg.orig.tar.gz: dojo-release-1.5.0-src+dfsg/dijit/_editor/nls/it/commands.js <==
({
	'bold': 'Grassetto',
	'copy': 'Copia',
	'cut': 'Taglia',
	'delete': 'Elimina',
	'indent': 'Rientro',
	'insertHorizontalRule': 'Righello orizzontale',
	'insertOrderedList': 'Elenco numerato',
	'insertUnorderedList': 'Elenco puntato',
	'italic': 'Corsivo',
	'justifyCenter': 'Allinea al centro',
	'justifyFull': 'Giustifica',
	'justifyLeft': 'Allinea a sinistra',
	'justifyRight': 'Allinea a destra',
	'outdent': 'Annulla rientro',
	'paste': 'Incolla',
	'redo': 'Ripristina',
	'removeFormat': 'Rimuovi formato',
	'selectAll': 'Seleziona tutto',
	'strikethrough': 'Barrato',
	'subscript': 'Pedice',
	'superscript': 'Apice',
	'underline': 'Sottolinea',
	'undo': 'Annulla',
	'unlink': 'Rimuovi collegamento',
	'createLink': 'Crea collegamento',
	'toggleDir': 'Attiva/Disattiva direzione',
	'insertImage': 'Inserisci immagine',
	'insertTable': 'Inserisci/Modifica tabella',
	'toggleTableBorder': 'Attiva/Disattiva bordo tabella',
	'deleteTable': 'Elimina tabella',
	'tableProp': 'Proprietà tabella',
	'htmlToggle': 'Origine HTML',
	'foreColor': 'Colore primo piano',
	'hiliteColor': 'Colore sfondo',
	'plainFormatBlock': 'Stile paragrafo',
	'formatBlock': 'Stile paragrafo',
	'fontSize': 'Dimensione carattere',
	'fontName': 'Nome carattere',
	'tabIndent': 'Rientro tabulazione',
	"fullScreen": "Attiva/Disattiva schermo intero",
	"viewSource": "Visualizza origine HTML",
	"print": "Stampa",
	"newPage": "Nuova pagina",
	/* Error messages */
	'systemShortcut': 'La azione "${0}" è disponibile solo nel browser tramite un tasto di scelta rapida. Utilizzare ${1}.'
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dijit/_editor/nls/it/commands.js <==
define(
//begin v1.x content
({
	'bold': 'Grassetto',
	'copy': 'Copia',
	'cut': 'Taglia',
	'delete': 'Elimina',
	'indent': 'Rientra',
	'insertHorizontalRule': 'Righello orizzontale',
	'insertOrderedList': 'Elenco numerato',
	'insertUnorderedList': 'Elenco puntato',
	'italic': 'Corsivo',
	'justifyCenter': 'Allinea al centro',
	'justifyFull': 'Giustifica',
	'justifyLeft': 'Allinea a sinistra',
	'justifyRight': 'Allinea a destra',
	'outdent': 'Rimuovi rientro',
	'paste': 'Incolla',
	'redo': 'Ripristina',
	'removeFormat': 'Rimuovi formato',
	'selectAll': 'Seleziona tutto',
	'strikethrough': 'Barrato',
	'subscript': 'Pedice',
	'superscript': 'Apice',
	'underline': 'Sottolineato',
	'undo': 'Annulla',
	'unlink': 'Rimuovi collegamento',
	'createLink': 'Crea collegamento',
	'toggleDir': 'Inverti direzione',
	'insertImage': 'Inserisci immagine',
	'insertTable': 'Inserisci/Modifica tabella',
	'toggleTableBorder': 'Mostra/Nascondi margine tabella',
	'deleteTable': 'Elimina tabella',
	'tableProp': 'Proprietà tabella',
	'htmlToggle': 'Origine HTML',
	'foreColor': 'Colore primo piano',
	'hiliteColor': 'Colore sfondo',
	'plainFormatBlock': 'Stile paragrafo',
	'formatBlock': 'Stile paragrafo',
	'fontSize': 'Dimensione carattere',
	'fontName': 'Nome carattere',
	'tabIndent': 'Rientranza tabulazione',
	"fullScreen": "Attiva/Disattiva schermo intero",
	"viewSource": "Visualizza origine HTML",
	"print": "Stampa",
	"newPage": "Nuova pagina",
	/* Error messages */
	'systemShortcut': 'Azione "${0}" disponibile sul proprio browser solo mediante i tasti di scelta rapida della tastiera. Utilizzare ${1}.'
})

//end v1.x content
);
